@@ -12,16 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Utility functions"""
+"""Utility functions."""
 import logging
 import inspect
 
 
-def get_class_logger(obj):
-    """
-    Obtain a logger object for a class.
-    :param obj: the class object
-    :return: the logger
+def get_class_logger(obj: object) -> logging.Logger:
+    """Obtains a logger object for a class.
+
+    Args:
+        obj (object): The class object.
+
+    Returns:
+        logging.Logger: The class' logger.
     """
     klass = list(filter(lambda m: m[0] == '__class__', inspect.getmembers(obj)))[0][1]
     cls_name = str(klass)[8:-2]
